CardNumberInputFormatter class

TextEditingValue 相关说明:

  • int baseOffset:开始的位置
  • int extentOffset:结束的位置
  • TextAffinity affinity:光标的位置
  • bool isDirectional:是否消除了其基础和范围的歧义(不懂可以直接忽略) 银行卡号输入格式化器 格式:每4位添加一个空格,如 1234 1234 1234 1234 123
Inheritance

Constructors

CardNumberInputFormatter()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

formatEditUpdate(TextEditingValue oldValue, TextEditingValue newValue) TextEditingValue
Called when text is being typed or cut/copy/pasted in the EditableText.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited