WApp class

应用初始化和运行工具类

Constructors

WApp()
创建应用实例

Properties

builder TransitionBuilder
设置应用构建器
no getter
checkboxSelectedIcon Widget
no getter
checkboxUnselectedIcon Widget
no getter
defaultTransition ← Transition
设置默认过渡动画
no getter
designWidth double
设置设计稿宽度
no getter
no getter
envFileName String
设置环境变量文件名
no getter
fallbackLocale Locale
设置fallback语言
no getter
getPages List<GetPage>
设置路由页面列表
no getter
hashCode int
The hash code for this object.
no setterinherited
initialRoute String
设置初始路由
no getter
locale Locale
设置当前语言
no getter
设置导航观察者列表
no getter
orientations List<DeviceOrientation>
设置屏幕方向
no getter
radioSelectedIcon Widget
no getter
radioUnselectedIcon Widget
no getter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
theme ThemeData
设置应用主题
no getter
title String
设置应用标题
no getter
translations ← Translations
设置翻译资源
no getter
turnOffLog bool
设置是否关闭日志
no getter

Methods

init({VoidCallback? onLazyInit, List<Future<void>>? customTasks}) Future<void>
初始化应用
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
run({String? initialRoute, List<GetPage>? getPages, TransitionBuilder? builder, List<NavigatorObserver>? navigatorObservers, Transition? defaultTransition, ThemeData? theme, Translations? translations, Locale? locale, Locale? fallbackLocale}) → void
运行应用
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited