WFormCheckboxConfig class

复选框配置类,定义复选框的样式和行为

Constructors

WFormCheckboxConfig()

Properties

disableIcon Widget
禁用状态图标 setter
no getter
enabled bool
是否启用 setter
no getter
hashCode int
The hash code for this object.
no setterinherited
iconYOffset double
图标 Y 轴偏移 setter
no getter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedIcon Widget
选中状态图标 setter
no getter
spacing double
间距 setter
no getter
unselectedIcon Widget
未选中状态图标 setter
no getter

Methods

build({required String name, required Widget title, bool initialValue = false, ValueChanged<bool?>? onChanged}) WFormCheckbox
构建 WFormCheckbox 组件
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited