WNavBar class

Inheritance
Available extensions

Constructors

WNavBar({Key? key, required WNavBarConfig config, required Widget itemBuilder(BuildContext, int, bool), Future<bool?>? onItemTap(int)?, required WNavController controller, TickerProvider? vsync})
const

Properties

config WNavBarConfig
标签栏配置
final
controller WNavController
导航栏控制器
final
hashCode int
The hash code for this object.
no setterinherited
itemBuilder Widget Function(BuildContext, int, bool)
导航项构建器
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
notificationListener WNotificationListener<Notification>

Available on Widget, provided by the WNotificationListenerExtension extension

创建 WNotificationListener 实例
no setter
onItemTap Future<bool?>? Function(int)?
导航项点击回调
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
vsync TickerProvider?
提供 vsync
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<WNavBar>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
expanded([int flex = 1]) Widget

Available on Widget, provided by the WidgetExtension extension

将 Widget 包装在 Expanded 中
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toButton({GestureTapCallback? onTap, GestureLongPressCallback? onLongPress, WButtonConfig? config}) Widget

Available on Widget, provided by the WidgetExtension extension

将 Widget 包装在 WButton 中
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited
withBottomPadding(double padding) Widget

Available on Widget, provided by the WidgetExtension extension

添加底部 padding
withBottomSafeSpace() Widget

Available on Widget, provided by the WidgetExtension extension

添加底部安全空间(适配底部导航栏)
withBottomSpace(double height) Widget

Available on Widget, provided by the WidgetExtension extension

添加自定义底部空间
withContainer(WContainerConfig config) Widget

Available on Widget, provided by the WidgetExtension extension

将 Widget 包装在 Container 中
withHorizontalPadding(double padding) Widget

Available on Widget, provided by the WidgetExtension extension

添加水平 padding
withLeftPadding(double padding) Widget

Available on Widget, provided by the WidgetExtension extension

添加左侧 padding
withRightPadding(double padding) Widget

Available on Widget, provided by the WidgetExtension extension

添加右侧 padding
withTopPadding(double padding) Widget

Available on Widget, provided by the WidgetExtension extension

添加顶部 padding
withTopSafeSpace() Widget

Available on Widget, provided by the WidgetExtension extension

添加顶部安全空间(适配状态栏)
withVerticalPadding(double padding) Widget

Available on Widget, provided by the WidgetExtension extension

添加垂直 padding

Operators

operator ==(Object other) bool
The equality operator.
inherited