WRegExpStr class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- bankCard → const String
- chineseName → const String
- date → const String
- decimal → const String
- email → const String
- idCard → const String
- integer → const String
- ipV4 → const String
- macAddress → const String
- number → const String
- password → const String
- phone → const String
- positiveDecimal → const String
- positiveInteger → const String
- positiveNumber → const String
- postalCode → const String
- url → const String