WClipRRectConfig class
圆角裁剪配置类,用于配置裁剪的圆角
Constructors
Properties
- borderRadius ← BorderRadiusGeometry
-
设置圆角半径
no getter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
borderRadiusAll(
double radius) → WClipRRectConfig - 设置所有角的圆角半径
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited