WFormButton class
表单按钮组件,用于创建可点击的表单字段
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- WFormButton
- Available extensions
Constructors
-
WFormButton({Key? key, required WFormButtonConfig config, required String name, required void onTap(String? value, ValueChanged<
String> didChange), Widget selectedWidgetBuilder(String value)?, String? initialValue}) -
构造函数
const
Properties
- config → WFormButtonConfig
-
按钮配置
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialValue → String?
-
初始值
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- name → String
-
字段名称
final
-
notificationListener
→ WNotificationListener<
Notification> -
Available on Widget, provided by the WNotificationListenerExtension extension
创建 WNotificationListener 实例no setter -
onTap
→ void Function(String? value, ValueChanged<
String> didChange) -
点击回调函数
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectedWidgetBuilder → Widget Function(String value)?
-
选中值的 widget 构建器
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
expanded(
[int flex = 1]) → Widget -
Available on Widget, provided by the WidgetExtension extension
将 Widget 包装在 Expanded 中 -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toButton(
{GestureTapCallback? onTap, GestureLongPressCallback? onLongPress, WButtonConfig? config}) → Widget -
Available on Widget, provided by the WidgetExtension extension
将 Widget 包装在 WButton 中 -
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
-
withBottomPadding(
double padding) → Widget -
Available on Widget, provided by the WidgetExtension extension
添加底部 padding -
withBottomSafeSpace(
) → Widget -
Available on Widget, provided by the WidgetExtension extension
添加底部安全空间(适配底部导航栏) -
withBottomSpace(
double height) → Widget -
Available on Widget, provided by the WidgetExtension extension
添加自定义底部空间 -
withContainer(
WContainerConfig config) → Widget -
Available on Widget, provided by the WidgetExtension extension
将 Widget 包装在 Container 中 -
withHorizontalPadding(
double padding) → Widget -
Available on Widget, provided by the WidgetExtension extension
添加水平 padding -
withLeftPadding(
double padding) → Widget -
Available on Widget, provided by the WidgetExtension extension
添加左侧 padding -
withRightPadding(
double padding) → Widget -
Available on Widget, provided by the WidgetExtension extension
添加右侧 padding -
withTopPadding(
double padding) → Widget -
Available on Widget, provided by the WidgetExtension extension
添加顶部 padding -
withTopSafeSpace(
) → Widget -
Available on Widget, provided by the WidgetExtension extension
添加顶部安全空间(适配状态栏) -
withVerticalPadding(
double padding) → Widget -
Available on Widget, provided by the WidgetExtension extension
添加垂直 padding
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited