WFormButtonConfig class
表单按钮配置类,定义按钮的样式和行为
Constructors
Properties
-
actions
← List<
Widget> -
操作按钮列表 setter
no getter
- containerDecoration ← Decoration
-
容器装饰 setter
no getter
- containerMargin ← EdgeInsetsGeometry
-
容器边距 setter
no getter
- containerPadding ← EdgeInsetsGeometry
-
容器内边距 setter
no getter
- enabled ← bool
-
是否启用 setter
no getter
- hashCode → int
-
The hash code for this object.
no setterinherited
- height ← double
-
高度 setter
no getter
- hintWidget ← Widget
-
提示 widget setter
no getter
- leading ← Widget
-
左侧组件 setter
no getter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- yOffset ← double
-
Y轴偏移 setter
no getter
Methods
-
build(
{required String name, required void onTap(String? value, ValueChanged< String> didChange), Widget selectedWidgetBuilder(String value)?, String? initialValue}) → WFormButton - 构建 WFormButton 组件
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited