WFormRadioGroupConfig class
单选按钮组配置类,定义单选按钮组的样式和行为
Constructors
Properties
- enabled ← bool
-
是否启用 setter
no getter
- hashCode → int
-
The hash code for this object.
no setterinherited
- iconYOffset ← double
-
图标 Y 轴偏移 setter
no getter
- lineSpacing ← double
-
行间距 setter
no getter
- padding ← EdgeInsetsGeometry?
-
内容内边距 setter
no getter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectedIcon ← Widget
-
选中状态图标 setter
no getter
- spacing ← double
-
间距 setter
no getter
- style ← TextStyle?
-
文本样式 setter
no getter
- unselectedIcon ← Widget
-
未选中状态图标 setter
no getter
Methods
-
build<
T> ({required String name, required Map< T, String> items, Widget itemBuilder(BuildContext, T, String, bool)?, Widget itemChildBuilder(BuildContext, T, String, bool)?, T? initialValue, ValueChanged<T?> ? onChanged}) → WFormRadioGroup<T> - 构建 WFormRadioGroup 组件
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited