WFormValidatorsConfig class
表单验证器配置类,定义验证器的行为
Constructors
Properties
- customErrorHandler ← dynamic Function(String fieldName, String error)
-
自定义错误处理函数 setter
no getter
- hashCode → int
-
The hash code for this object.
no setterinherited
- itemValidationCallback ← dynamic Function(String fieldName, bool isValid, String? errorText)
-
每一项校验的结果回调函数 setter
no getter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
shouldSkipValidation
← bool Function(String fieldName, Map<
String, dynamic> ? formValues) -
在校验前判断是否要跳过当前校验的回调函数 setter
no getter
- showBorderError ← bool
-
是否显示边框错误 setter
no getter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited