WNavController class
- Inheritance
-
- Object
- ChangeNotifier
- WNavController
Constructors
Properties
-
animation
→ Animation<
double> -
no setter
- currentIndex ↔ int
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- indexIsChanging → bool
-
no setter
- length → int
-
final
- offset → double
-
no setter
- previousIndex → int
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- vsync → TickerProvider
-
final
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
animateTo(
int index, {Duration? duration, Curve curve = Curves.ease}) → Future< void> -
dispose(
) → void -
Discards any resources used by the object.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
setIndex(
int index) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited