WPerformance class
性能监控工具类
Constructors
- WPerformance()
-
构造函数
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
performanceData
→ Map<
String, List< PerformanceData> > -
获取性能数据
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clear(
) → void - 清空性能数据
-
end(
String tag, String id) → int - 结束性能监控
-
monitor<
T> (String tag, Future< T> function()) → Future<T> - 监控函数执行时间
-
monitorSync<
T> (String tag, T function()) → T - 监控同步函数执行时间
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
start(
String tag) → String - 开始性能监控
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited