WQrViewOverlayShape class
二维码扫描框样式配置类
Constructors
Properties
- borderLength → double
-
边框长度
final
- borderRadius → double
-
边框圆角
final
- borderWidth → double
-
边框宽度
final
- cutOutBottomOffset → double
-
扫描框底部偏移
final
- cutOutHeight → double
-
扫描框高度
final
- cutOutWidth → double
-
扫描框宽度
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- overlayColor → Color
-
遮罩颜色
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited