WRow class
Constructors
- WRow()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
bottom(
{required List< Widget> children}) → Row - 创建底部对齐的 Row
-
iconWithText(
{required Widget icon, required double spacing, required Widget text}) → Row - 创建包含图标、间距和文本的 Row
-
min(
{CrossAxisAlignment crossAxisAlignment = CrossAxisAlignment.center, required List< Widget> children}) → Row - 创建主轴尺寸最小的 Row
-
top(
{required List< Widget> children}) → Row - 创建顶部对齐的 Row